<!DOCTYPE kpartgui>
<kpartgui name="kenolaba" version="5">

 <MenuBar>
   <Menu name="game"><text>&amp;Game</text>
      <Action name="game_net"/>
   </Menu>
   <Menu name="move"><text>&amp;Move</text>
      <Action name="move_stop"/>
      <Action name="move_back"/>
      <Action name="move_forward"/>
   </Menu>
   <Menu name="edit"><text>&amp;Edit</text>
      <Action name="edit_modify"/>
      <Separator/>
      <Action name="edit_save"/>
      <Action name="edit_restore"/>
   </Menu>
   <Menu name="settings"><text>&amp;Settings</text>
      <Action name="options_iplay" append="save_merge"/>
      <Action name="options_moveSlow" append="save_merge"/>
      <Action name="options_renderBalls" append="save_merge"/>
      <Action name="options_showSpy" append="save_merge"/>
   </Menu>
 </MenuBar>

 <Menu name="rmbPopup">
   <Menu name="rmbSettings"><text>&amp;Settings</text>
     <Action name="options_show_menubar"/>
     <Action name="options_show_toolbar"/>
     <Action name="options_show_statusbar"/>
     <Separator/>
     <Action name="options_save_options"/>
   </Menu>
   <Separator/>
   <Action name="game_new"/>
   <Action name="move_back"/>
   <Action name="move_hint"/>
   <Action name="move_stop"/>
 </Menu>	

 <ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
   <Action name="game_new"/>
   <Action name="edit_modify"/>
   <Separator/>
   <Action name="move_back"/>
   <Action name="move_hint"/>
   <Action name="move_stop"/>
   <Separator/>
   <Action name="game_net"/>
 </ToolBar>

</kpartgui>
