<!DOCTYPE kpartgui>
<kpartgui name="ktuberling" version="1">
<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
    <Action name="game_save_picture" append="save_merge"/>
  </Menu>
  <Menu name="playground"><text>&amp;Playground</text>
    <Action name="playground_potato_guy"/>
    <Action name="playground_penguin"/>
    <Action name="playground_aquarium"/>
  </Menu>
  <Menu name="speech"><text>&amp;Speech</text>
    <Action name="speech_no_sound"/>
    <Separator/>
    <Action name="speech_danish"/>
    <Action name="speech_german"/>
    <Action name="speech_english"/>
    <Action name="speech_spanish"/>
    <Action name="speech_finnish"/>
    <Action name="speech_french"/>
    <Action name="speech_italian"/>
    <Action name="speech_lowsaxon"/>
    <Action name="speech_dutch"/>
    <Action name="speech_portuguese"/>
    <Action name="speech_romanian"/>
    <Action name="speech_slovak"/>
    <Action name="speech_slovenian"/>
    <Action name="speech_swedish"/>
    <Action name="speech_serbian"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
  <Action name="game_new"/>
  <Action name="game_load"/>
  <Action name="game_save"/>
  <Action name="game_print"/>
  <Separator/>
  <Action name="edit_undo"/>
  <Action name="edit_redo"/>
</ToolBar>
</kpartgui>
