( cd usr/share/doc/HTML/en/lskat ; rm -rf common )
( cd usr/share/doc/HTML/en/lskat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfouleggs ; rm -rf common )
( cd usr/share/doc/HTML/en/kfouleggs ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwin4 ; rm -rf common )
( cd usr/share/doc/HTML/en/kwin4 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kreversi ; rm -rf common )
( cd usr/share/doc/HTML/en/kreversi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd usr/share/doc/HTML/en/kgoldrunner ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kpat ; rm -rf common )
( cd usr/share/doc/HTML/en/kpat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konquest ; rm -rf common )
( cd usr/share/doc/HTML/en/konquest ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmines ; rm -rf common )
( cd usr/share/doc/HTML/en/kmines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/klines ; rm -rf common )
( cd usr/share/doc/HTML/en/klines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksokoban ; rm -rf common )
( cd usr/share/doc/HTML/en/ksokoban ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksame ; rm -rf common )
( cd usr/share/doc/HTML/en/ksame ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kpoker ; rm -rf common )
( cd usr/share/doc/HTML/en/kpoker ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbackgammon ; rm -rf common )
( cd usr/share/doc/HTML/en/kbackgammon ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kenolaba ; rm -rf common )
( cd usr/share/doc/HTML/en/kenolaba ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd usr/share/doc/HTML/en/kjumpingcube ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd usr/share/doc/HTML/en/kbattleship ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksmiletris ; rm -rf common )
( cd usr/share/doc/HTML/en/ksmiletris ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksnake ; rm -rf common )
( cd usr/share/doc/HTML/en/ksnake ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd usr/share/doc/HTML/en/kspaceduel ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd usr/share/doc/HTML/en/kblackbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksirtet ; rm -rf common )
( cd usr/share/doc/HTML/en/ksirtet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kshisen ; rm -rf common )
( cd usr/share/doc/HTML/en/kshisen ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/atlantik ; rm -rf common )
( cd usr/share/doc/HTML/en/atlantik ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbounce ; rm -rf common )
( cd usr/share/doc/HTML/en/kbounce ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kasteroids ; rm -rf common )
( cd usr/share/doc/HTML/en/kasteroids ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktron ; rm -rf common )
( cd usr/share/doc/HTML/en/ktron ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kolf ; rm -rf common )
( cd usr/share/doc/HTML/en/kolf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/en/ktuberling ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/klickety ; rm -rf common )
( cd usr/share/doc/HTML/en/klickety ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/en/kmahjongg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/katomic ; rm -rf common )
( cd usr/share/doc/HTML/en/katomic ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib64 ; rm -rf libkdegames.so.1 )
( cd usr/lib64 ; ln -sf libkdegames.so.1.2.0 libkdegames.so.1 )
( cd usr/lib64 ; rm -rf libkdegames.so )
( cd usr/lib64 ; ln -sf libkdegames.so.1.2.0 libkdegames.so )
( cd usr/lib64 ; rm -rf libatlantic.so.1 )
( cd usr/lib64 ; ln -sf libatlantic.so.1.2.0 libatlantic.so.1 )
( cd usr/lib64 ; rm -rf libatlantic.so )
( cd usr/lib64 ; ln -sf libatlantic.so.1.2.0 libatlantic.so )
( cd usr/lib64 ; rm -rf libatlantikclient.so.1 )
( cd usr/lib64 ; ln -sf libatlantikclient.so.1.2.0 libatlantikclient.so.1 )
( cd usr/lib64 ; rm -rf libatlantikclient.so )
( cd usr/lib64 ; ln -sf libatlantikclient.so.1.2.0 libatlantikclient.so )
( cd usr/lib64 ; rm -rf libatlantikui.so.1 )
( cd usr/lib64 ; ln -sf libatlantikui.so.1.2.0 libatlantikui.so.1 )
( cd usr/lib64 ; rm -rf libatlantikui.so )
( cd usr/lib64 ; ln -sf libatlantikui.so.1.2.0 libatlantikui.so )
( cd usr/lib64 ; rm -rf libkolf.so.1 )
( cd usr/lib64 ; ln -sf libkolf.so.1.2.0 libkolf.so.1 )
( cd usr/lib64 ; rm -rf libkolf.so )
( cd usr/lib64 ; ln -sf libkolf.so.1.2.0 libkolf.so )
