<!DOCTYPE kpartgui>
<kpartgui name="kpoker" version="2">

<MenuBar>
  <Menu name="settings"><text>&amp;Settings</text>
	<Separator append="show_merge"/>
	<Action name="options_sound" append="show_merge"/>
	<Action name="options_blinking" append="show_merge"/>
	<Action name="options_adjust" append="show_merge"/>
  </Menu>
</MenuBar>

<Menu name="popup">
	<Action name="options_show_menubar"/>
	<Action name="options_show_statusbar"/>
	<Separator/>
	<Action name="options_sound"/>
	<Action name="options_blinking"/>
	<Action name="options_adjust"/>
	<Action name="options_save_options"/>
	<Separator/>
	<Action name="options_configure_carddeck"/>
	<Action name="options_configure"/>
	<Separator/>
	<Action name="game_new"/>
	<Separator/>
	<Action name="game_quit"/>
</Menu>

</kpartgui>
