<!DOCTYPE kpartgui>
<kpartgui name="kspaceduel" version="6">

<MenuBar>
   <Menu name="game"><text>&amp;Game</text>
      <Action name="new_round" append="new_merge"/>
   </Menu>
</MenuBar>

<Toolbar name="mainToolBar"><text>Main Toolbar</text>
   <Action name="game_new"/>
   <Action name="new_round"/>
   <Action name="game_pause"/>
</Toolbar>

</kpartgui>
