<!DOCTYPE kpartgui>
<kpartgui name="kbackgammon" version="3">

<MenuBar>
  <Menu name="move"><text>&amp;Move</text>
	<Action name="move_load" append="move_undo_merge"/>
 	<Action name="move_cube" append="move_turn_merge"/>
    <Action name="move_engine"/>
  </Menu>
  <Menu name="command_menu"><text>&amp;Command</text>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="options_textbar" append="show_merge"/>
  </Menu>
   <Menu name="help"><text>&amp;Help</text>
    <Action name="help_www"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true"><text>Main Toolbar</text>
  <Action name="game_new"/>
  <Separator/>
  <Action name="move_undo"/>
  <Action name="move_redo"/>
  <Action name="move_load"/>
  <Separator/>
  <Action name="move_roll"/>
  <Action name="move_end_turn"/>
  <Action name="move_cube"/>
</ToolBar>

<ToolBar name="cmdToolBar" noMerge="1" fullWidth="true"><text>Command Toolbar</text>
  <Action name="command_label"/>
  <Action name="command_lineedit"/>
</ToolBar>

<StatusBar/>

<Menu name="popup">
  <Action name="options_show_menubar"/>
  <Separator/>
  <Action name="move_undo"/>
  <Action name="move_redo"/>
  <Action name="move_load"/>
  <Separator/>
  <Action name="move_roll"/>
  <Action name="move_end_turn"/>
  <Action name="move_cube"/>
</Menu>

</kpartgui>
