<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE kpartgui>
<kpartgui name="klickety" version="4">

<Menu name="popup">
  <Action name="options_show_menubar"/>
  <Separator/>
  <Action name="game_new"/>
  <Separator/>
  <Action name="game_pause"/>
  <Action name="game_highscores"/>
  <Action name="game_print"/>
  <Separator/>
  <Action name="game_quit"/>
</Menu>

</kpartgui>
