<!DOCTYPE kpartgui>
<kpartgui name="kjumpingcube" version="4">

<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
    <Action name="game_stop"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
    <Action name="game_new"/>
    <Action name="game_open"/>
    <Action name="game_save"/>
    <Separator/>
    <Action name="game_stop"/>
    <Action name="game_hint"/>
    <Action name="move_undo"/>
</ToolBar>

</kpartgui>
