<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="Kolf" version="11">
	<MenuBar>
		<Menu name="game">
			<Action name="savegame" append="save_merge" />
			<Action name="savegameas" append="save_merge" />
			<Action name="saveshotas" append="save_merge" />

			<Action name="aboutcourse" />
		</Menu>

		<Menu name="hole"><text>Ho&amp;le</text>
			<Action name="editing" />
			<Separator />
			<Action name="newhole" />
			<Action name="clearhole" />
			<Separator />
			<Action name="resethole" />
			<Action name="restarthole" />
			<Separator />
			<Action name="showinfo" />
			<Action name="undoshot" />
			<Action name="replay" />
		</Menu>
		
		<Menu name="go_course"><text>&amp;Go</text>
			<Action name="switchhole" />
			<Separator />
			<Action name="nexthole" />
			<Action name="prevhole" />
			<Action name="firsthole" />
			<Action name="lasthole" />
			<Separator />
			<Action name="randhole" />
		</Menu>

		<Menu name="settings">
			<Action name="usemouse" append="save_merge"/>
			<Action name="useadvancedputting"  append="save_merge"/>
			<Action name="showguideline" append="save_merge"/>
			<Action name="sound" append="save_merge"/>
			<Separator append="save_merge"/>
			<Action name="enableAll" append="save_merge"/>
			<Separator append="save_merge"/>
			<Action name="reloadplugins" append="save_merge"/>
			<Action name="showplugins" append="save_merge"/>
		</Menu>

		<Menu name="help">
			<Action name="tutorial" />
		</Menu>
	</MenuBar>

	<ToolBar name="mainToolBar" fullWidth="true">
		<Action name="game_new" />
		<Action name="game_save" />
		<Separator />
		<Action name="game_end" />
		<Separator />
		<Action name="showinfo" />
		<Action name="undoshot" />
		<Action name="editing" />
		<Separator />
		<Action name="prevhole" />
		<Action name="nexthole" />
		<Separator />
		<Action name="switchhole" />
	</ToolBar>

	<StatusBar />
</kpartgui>
