<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="4" name="KGoldrunner" >
<MenuBar>
    <Menu name="game" >
	<Action append="new_merge"	name="play_any" />
	<Action append="new_merge"	name="play_next" />
	<Action append="new_merge"	name="tutorial" />
	<Action append="save_merge"	name="save_edits" />
	<Action append="misc_merge"	name="get_hint" />
	<Action append="misc_merge"	name="kill_hero" />
    </Menu>
    <Menu name="editor" > <text>&amp;Editor</text>
	<Action				name="create" />
	<Action				name="edit_any" />
	<Action				name="edit_next" />
	<Separator/>
	<Action				name="save_edits" />
	<Action				name="move_level" />
	<Action				name="delete_level" />
	<Separator/>
	<Action				name="create_game" />
	<Action				name="edit_game" />
    </Menu>
    <Menu name="landscapes" > <text>&amp;Landscapes</text>
	<Action				name="kgoldrunner" />
	<Action				name="apple_2" />
	<Action				name="ice_cave" />
	<Action				name="midnight" />
	<Action				name="kde_kool" />
    </Menu>
    <Menu name="settings" >
	<Action append="save_merge"	name="mouse_mode" />
	<Action append="save_merge"	name="keyboard_mode" />
	<Separator append="save_merge" />
	<Action append="save_merge"	name="normal_speed" />
	<Action append="save_merge"	name="beginner_speed" />
	<Action append="save_merge"	name="champion_speed" />
	<Action append="save_merge"	name="increase_speed" />
	<Action append="save_merge"	name="decrease_speed" />
	<Separator append="save_merge" />
	<Action append="save_merge"	name="trad_rules" />
	<Action append="save_merge"	name="kgr_rules" />
	<Separator append="save_merge" />
	<Action append="save_merge"	name="larger_area" />
	<Action append="save_merge"	name="smaller_area" />
    </Menu>
    <Menu name="help" >
	<Action				name="tutorial" />
	<Action				name="get_hint" />
    </Menu>
</MenuBar>

<ActionProperties>
    <Action shortcut="P;Escape"		name="game_pause" />
    <Action shortcut="S"		name="game_save" />
    <Action shortcut="Ctrl+S"		name="save_edits" />

    <Action shortcut="Shift+G"		name="kgoldrunner" />
    <Action shortcut="Shift+A"		name="apple_2" />
    <Action shortcut="Shift+I"		name="ice_cave" />
    <Action shortcut="Shift+M"		name="midnight" />
    <Action shortcut="Shift+K"		name="kde_kool" />

    <Action shortcut="Up;I"		name="move_up" />
    <Action shortcut="Right;L"		name="move_right" />
    <Action shortcut="Down;K"		name="move_down" />
    <Action shortcut="Left;J"		name="move_left" />
    <Action shortcut="Space"		name="stop" />
    <Action shortcut="Z;U"		name="dig_left" />
    <Action shortcut="C;O"		name="dig_right" />

    <Action shortcut="+"		name="increase_speed" />
    <Action shortcut="-"		name="decrease_speed" />
</ActionProperties>
</kpartgui>
