<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kshisen" version="10">
<MenuBar>
  <Menu name="move"><!--
    <Action name="move_solvable"/>
    <Action name="move_finish"/>-->
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
  <Action name="move_undo"/>
  <Action name="move_redo"/>
  <Separator/>
  <Action name="game_pause"/>
</ToolBar>
<StatusBar/>
</kpartgui>
