<!DOCTYPE kpartgui>
<kpartgui name="atlantik" version="2">
<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
    <Action name="showeventlog"/>
  </Menu>
  <Menu name="move"><text>&amp;Move</text>
    <Action name="move_roll"/>
    <Action name="buy_estate"/>
    <Action name="auction"/>
    <Action name="move_endturn"/>
    <Action name="move_jailcard"/>
    <Action name="move_jailpay"/>
    <Action name="move_jailroll"/>
  </Menu>
</MenuBar>
<ToolBar name="moveToolBar">
    <Action name="move_roll"/>
    <Action name="buy_estate"/>
    <Action name="auction"/>
    <Action name="move_endturn"/>
    <Action name="move_jailpay"/>
</ToolBar>
</kpartgui>
