<!DOCTYPE kpartgui>
<kpartgui name="ksame" version="10">
<MenuBar>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
	<Action name="random_board"/>
	<Action name="showNumberRemaining"/>
	<Separator/>
  	<Action name="options_configure_keybinding"/>
	<Action name="options_configure_notifications"/>
  </Menu>	
</MenuBar>

<ToolBar name="mainToolBar"><text>Main Toolbar</text>
  <Action name="game_new"/>
</ToolBar>

</kpartgui>
